library(testthat)
library(replicateBE)
test_check("replicateBE")
